<?php

/**
 * LICENSE: Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * PHP version 5
 *
 * @category  Microsoft
 *
 * @author    Azure PHP SDK <azurephpsdk@microsoft.com>
 * @copyright Microsoft Corporation
 * @license   http://www.apache.org/licenses/LICENSE-2.0  Apache License 2.0
 *
 * @link      https://github.com/windowsazure/azure-sdk-for-php
 */

namespace WindowsAzure\MediaServices\Models;

use WindowsAzure\Common\Internal\Validate;

/**
 * Represents storage account object used in media services.
 *
 * @category  Microsoft
 *
 * @author    Azure PHP SDK <azurephpsdk@microsoft.com>
 * @copyright Microsoft Corporation
 * @license   http://www.apache.org/licenses/LICENSE-2.0  Apache License 2.0
 *
 * @version   Release: 0.5.0_2016-11
 *
 * @link      https://github.com/windowsazure/azure-sdk-for-php
 */
class StorageAccount
{
    /**
     * Name.
     *
     * @var string
     */
    private $_name;

    /**
     * Is default.
     *
     * @var bool
     */
    private $_isDefault;

    /**
     * Create storage account from array.
     *
     * @param array $options Array containing values for object properties
     *
     * @return StorageAccount
     */
    public static function createFromOptions(array $options)
    {
        $storageAccount = new self();
        $storageAccount->fromArray($options);

        return $storageAccount;
    }

    /**
     * Create storage account.
     */
    public function __construct()
    {
    }

    /**
     * Fill storage account from array.
     *
     * @param array $options Array containing values for object properties
     */
    public function fromArray(array $options)
    {
        if (isset($options['Name'])) {
            Validate::isString($options['Name'], 'options[Name]');
            $this->_name = $options['Name'];
        }

        if (isset($options['IsDefault'])) {
            Validate::isBoolean($options['IsDefault'], 'options[IsDefault]');
            $this->_isDefault = $options['IsDefault'];
        }
    }

    /**
     * Get "Name".
     *
     * @return string
     */
    public function getName()
    {
        return $this->_name;
    }

    /**
     * Get "Is default".
     *
     * @return bool
     */
    public function getIsDefault()
    {
        return $this->_isDefault;
    }
}
